/* eslint-disable react/jsx-props-no-spreading */
import React, { FC, useState } from 'react';
import {
  Button,
  Card,
  CardActions,
  CardContent,
  TextField,
  Typography,
} from '@material-ui/core';
import { Control, Controller } from 'react-hook-form';
import { ReservationType } from 'types/ReservationType';
import { KeyboardDateTimePicker } from '@material-ui/pickers';
import { reservationPageStyle } from '../ReservationPage.style';

type TripStageProps = {
  control: Control<ReservationType>;
};

export const TripStage: FC<TripStageProps> = ({ control }: TripStageProps) => {
  const classes = reservationPageStyle();
  const [stage, setStage] = useState<string[]>(['']);
  const [value, setValue] = useState<string>('');

  const addStage = (): void => {
    setStage([...stage, value]);
  };

  return (
    <Card>
      {stage.map((field, index) => (
        <CardContent>
          <Typography
            variant="h6"
            component="h3"
            className={classes.paddingBottomKlein}
          >
            Stage {index}
          </Typography>
          <Controller
            as={<input hidden />}
            name={`tripStages[${index}].number`}
            control={control}
            defaultValue={index}
          />
          <Controller
            as={<TextField variant="outlined" fullWidth label="Location" />}
            name={`tripStages[${index}].location.address`}
            control={control}
            defaultValue={field}
          />
          <Controller
            control={control}
            name={`tripStages[${index}].estimatedBeAt`}
            as={({ ref, ...rest }) => (
              <KeyboardDateTimePicker
                margin="normal"
                id="date-picker-dialog"
                label="Date and Hour"
                defaultValue={field}
                format="dd/MM/yyyy"
                KeyboardButtonProps={{
                  'aria-label': 'Insert trip stage',
                }}
                {...rest}
              />
            )}
          />
        </CardContent>
      ))}
      <CardActions>
        <Button variant="outlined" onClick={addStage} type="button">
          Add stage
        </Button>
      </CardActions>
    </Card>
  );
};
